@@ -2,9 +2,6 @@
 
 __author__ = """rdnfn"""
 __email__ = "-"
-__version__ = "0.1.0"
+__version__ = "0.2.0"
 
-import beobench.experiment.scheduler
-
-from beobench.core import Env
 from beobench.utils import restart
